@@ -37,8 +37,11 @@ globalVariables(c("class_name",
                   "metric_2",
                   "minp",
                   "n",
+                  "name",
                   "n_classes",
                   "patch_id",
+                  "raster_sample_plots",
+                  "type",
                   "OK",
                   "value",
                   "values",
