@@ -53,8 +53,12 @@ lsm_c_area_cv.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 
 }
 
@@ -66,8 +70,12 @@ lsm_c_area_cv.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_area_cv
@@ -78,8 +86,12 @@ lsm_c_area_cv.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_area_cv
@@ -92,8 +104,12 @@ lsm_c_area_cv.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_area_cv
@@ -104,8 +120,12 @@ lsm_c_area_cv.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_c_area_cv_calc <- function(landscape, directions, resolution = NULL){
@@ -116,8 +136,7 @@ lsm_c_area_cv_calc <- function(landscape, directions, resolution = NULL){
                             resolution = resolution)
 
     # calculate cv
-    area_cv <- dplyr::summarise(dplyr::group_by(area, class),
-                                value = raster::cv(value))
+    area_cv <- stats::aggregate(area[, 5], by = area[, 2], FUN = raster::cv)
 
     tibble::tibble(
         level = "class",
