@@ -54,8 +54,12 @@ lsm_c_area_mn.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_area_mn
@@ -66,8 +70,12 @@ lsm_c_area_mn.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_area_mn
@@ -78,8 +86,12 @@ lsm_c_area_mn.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_area_mn
@@ -92,8 +104,12 @@ lsm_c_area_mn.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 
@@ -105,8 +121,12 @@ lsm_c_area_mn.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_area_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_c_area_mn_calc <- function(landscape, directions, resolution = NULL){
@@ -117,8 +137,7 @@ lsm_c_area_mn_calc <- function(landscape, directions, resolution = NULL){
                             resolution = resolution)
 
     # calculate mean
-    area_mean <- dplyr::summarise(dplyr::group_by(area, class),
-                                  value = mean(value))
+    area_mean <- stats::aggregate(area[, 5], by = area[, 2], FUN = mean)
 
     tibble::tibble(
         level = "class",
