@@ -61,8 +61,12 @@ lsm_c_circle_cv.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_circle_cv
@@ -73,8 +77,12 @@ lsm_c_circle_cv.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_circle_cv
@@ -85,8 +93,12 @@ lsm_c_circle_cv.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_circle_cv
@@ -99,31 +111,41 @@ lsm_c_circle_cv.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 
 #' @name lsm_c_circle_cv
 #' @export
 lsm_c_circle_cv.list <- function(landscape, directions = 8) {
+
     result <- lapply(X = landscape,
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_c_circle_cv_calc <- function(landscape, directions,
                                  resolution = NULL, points = NULL) {
 
+    # calculate circumscribing circle for each patch
     circle <- lsm_p_circle_calc(landscape,
                                 directions = directions,
                                 resolution = resolution, points = points)
 
-    circle_cv <-  dplyr::summarize(dplyr::group_by(circle, class),
-                                   value = raster::cv(value))
+    # summarise for classes
+    circle_cv <- stats::aggregate(x = circle[, 5], by = circle[, 2], FUN = raster::cv)
 
     tibble::tibble(
         level = "class",
