@@ -59,8 +59,12 @@ lsm_c_circle_mn.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_circle_mn
@@ -71,8 +75,12 @@ lsm_c_circle_mn.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_circle_mn
@@ -83,8 +91,12 @@ lsm_c_circle_mn.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_circle_mn
@@ -97,8 +109,12 @@ lsm_c_circle_mn.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_circle_mn
@@ -109,19 +125,24 @@ lsm_c_circle_mn.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_c_circle_mn_calc <- function(landscape, directions,
                                  resolution = NULL, points = NULL) {
 
+    # calculate circumscribing circle for each patch
     circle <- lsm_p_circle_calc(landscape,
                                 directions = directions,
                                 resolution = resolution, points = points)
 
-    circle_mn <-  dplyr::summarize(dplyr::group_by(circle, class),
-                                   value = mean(value))
+    # summarise for classes
+    circle_mn <- stats::aggregate(x = circle[, 5], by = circle[, 2], FUN = mean)
 
     tibble::tibble(
         level = "class",
