@@ -65,8 +65,12 @@ lsm_c_contig_mn.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_contig_mn
@@ -77,8 +81,12 @@ lsm_c_contig_mn.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_contig_mn
@@ -89,8 +97,12 @@ lsm_c_contig_mn.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_contig_mn
@@ -103,8 +115,12 @@ lsm_c_contig_mn.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_contig_mn
@@ -115,16 +131,20 @@ lsm_c_contig_mn.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_mn_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_c_contig_mn_calc <- function(landscape, directions) {
 
     contig <- lsm_p_contig_calc(landscape, directions = directions)
 
-    contig_mn <- dplyr::summarize(dplyr::group_by(contig, class),
-                                  value = mean(value))
+    contig_mn <- stats::aggregate(x = contig[, 5], by = contig[, 2],
+                                  FUN = mean)
 
     tibble::tibble(
         level = "class",
