@@ -66,8 +66,12 @@ lsm_c_contig_sd.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_contig_sd
@@ -78,8 +82,12 @@ lsm_c_contig_sd.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_contig_sd
@@ -90,8 +98,12 @@ lsm_c_contig_sd.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_contig_sd
@@ -104,8 +116,12 @@ lsm_c_contig_sd.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_contig_sd
@@ -116,16 +132,20 @@ lsm_c_contig_sd.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_c_contig_sd_calc <- function(landscape, directions) {
 
     contig <- lsm_p_contig_calc(landscape, directions = directions)
 
-    contig_sd <- dplyr::summarize(dplyr::group_by(contig, class),
-                                  value = stats::sd(value))
+    contig_sd <- stats::aggregate(x = contig[, 5], by = contig[, 2],
+                                  FUN = stats::sd)
 
     tibble::tibble(
         level = "class",
@@ -134,5 +154,4 @@ lsm_c_contig_sd_calc <- function(landscape, directions) {
         metric = "contig_sd",
         value = as.double(contig_sd$value)
     )
-
 }
