@@ -60,8 +60,12 @@ lsm_c_dcore_mn.RasterLayer <- function(landscape, directions = 8, consider_bound
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_dcore_mn
@@ -74,8 +78,12 @@ lsm_c_dcore_mn.RasterStack <- function(landscape, directions = 8, consider_bound
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_dcore_mn
@@ -88,8 +96,12 @@ lsm_c_dcore_mn.RasterBrick <- function(landscape, directions = 8, consider_bound
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_dcore_mn
@@ -104,8 +116,12 @@ lsm_c_dcore_mn.stars <- function(landscape, directions = 8, consider_boundary =
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_dcore_mn
@@ -118,8 +134,12 @@ lsm_c_dcore_mn.list <- function(landscape, directions = 8, consider_boundary = F
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_c_dcore_mn_calc <- function(landscape, directions, consider_boundary, edge_depth,
@@ -131,8 +151,7 @@ lsm_c_dcore_mn_calc <- function(landscape, directions, consider_boundary, edge_d
                               edge_depth = edge_depth,
                               points = points)
 
-    dcore_mn <- dplyr::summarise(dplyr::group_by(dcore, class),
-                                 value = mean(value))
+    dcore_mn <- stats::aggregate(x = dcore[, 5], by = dcore[, 2], FUN = mean)
 
     tibble::tibble(
         level = "class",
