@@ -65,8 +65,12 @@ lsm_c_dcore_sd.RasterLayer <- function(landscape, directions = 8, consider_bound
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_dcore_sd
@@ -79,8 +83,12 @@ lsm_c_dcore_sd.RasterStack <- function(landscape, directions = 8, consider_bound
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_dcore_sd
@@ -93,8 +101,12 @@ lsm_c_dcore_sd.RasterBrick <- function(landscape, directions = 8, consider_bound
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_dcore_sd
@@ -109,8 +121,12 @@ lsm_c_dcore_sd.stars <- function(landscape, directions = 8, consider_boundary =
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_dcore_sd
@@ -123,8 +139,12 @@ lsm_c_dcore_sd.list <- function(landscape, directions = 8, consider_boundary = F
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_c_dcore_sd_calc <- function(landscape, directions, consider_boundary, edge_depth,
@@ -136,8 +156,7 @@ lsm_c_dcore_sd_calc <- function(landscape, directions, consider_boundary, edge_d
                               edge_depth = edge_depth,
                               points = points)
 
-    dcore_sd <- dplyr::summarise(dplyr::group_by(dcore, class),
-                                 value = stats::sd(value))
+    dcore_sd <- stats::aggregate(x = dcore[, 5], by = dcore[, 2], FUN = stats::sd)
 
     tibble::tibble(
         level = "class",
