@@ -60,8 +60,12 @@ lsm_c_ndca.RasterLayer <- function(landscape, directions = 8, consider_boundary
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_ndca
@@ -74,8 +78,12 @@ lsm_c_ndca.RasterStack <- function(landscape, directions = 8, consider_boundary
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_ndca
@@ -88,8 +96,12 @@ lsm_c_ndca.RasterBrick <- function(landscape, directions = 8, consider_boundary
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_ndca
@@ -104,8 +116,12 @@ lsm_c_ndca.stars <- function(landscape, directions = 8, consider_boundary = FALS
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_c_ndca
@@ -118,8 +134,12 @@ lsm_c_ndca.list <- function(landscape, directions = 8, consider_boundary = FALSE
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_c_ndca_calc <- function(landscape, directions, consider_boundary, edge_depth,
@@ -133,7 +153,7 @@ lsm_c_ndca_calc <- function(landscape, directions, consider_boundary, edge_depth
                              points = points)
 
     # summarise for each class
-    ndca <- dplyr::summarise(dplyr::group_by(ndca, class), value = sum(value))
+    ndca <- stats::aggregate(x = ndca[, 5], by = ndca[, 2], FUN = sum)
 
     tibble::tibble(
         level = "class",
