@@ -53,8 +53,12 @@ lsm_l_area_cv.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_area_cv
@@ -65,8 +69,12 @@ lsm_l_area_cv.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_area_cv
@@ -77,8 +85,12 @@ lsm_l_area_cv.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_area_cv
@@ -91,8 +103,12 @@ lsm_l_area_cv.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_area_cv
@@ -103,8 +119,12 @@ lsm_l_area_cv.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_area_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_area_cv_calc <- function(landscape, directions, resolution = NULL){
@@ -115,15 +135,13 @@ lsm_l_area_cv_calc <- function(landscape, directions, resolution = NULL){
                                   resolution = resolution)
 
     # calculate cv
-     area_cv <- dplyr::summarise(area_patch, value = raster::cv(value))
+    area_cv <- raster::cv(area_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "area_cv",
-        value = as.double(area_cv$value)
+        value = as.double(area_cv)
     )
 }
-
-
