@@ -59,8 +59,12 @@ lsm_l_circle_cv.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_circle_cv
@@ -71,8 +75,12 @@ lsm_l_circle_cv.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_circle_cv
@@ -83,8 +91,12 @@ lsm_l_circle_cv.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_circle_cv
@@ -97,8 +109,12 @@ lsm_l_circle_cv.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_circle_cv
@@ -109,25 +125,30 @@ lsm_l_circle_cv.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_circle_cv_calc <- function(landscape, directions,
                                  resolution = NULL, points = NULL) {
 
-    circle_cv <- dplyr::summarize(lsm_p_circle_calc(landscape,
-                                                    directions = directions,
-                                                    resolution = resolution,
-                                                    points = points),
-                                  value = raster::cv(value))
+    circle_patch <- lsm_p_circle_calc(landscape,
+                                      directions = directions,
+                                      resolution = resolution,
+                                      points = points)
+
+    circle_cv <- raster::cv(circle_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "circle_cv",
-        value = as.double(circle_cv$value)
+        value = as.double(circle_cv)
     )
 }
 
