@@ -60,8 +60,12 @@ lsm_l_circle_sd.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_circle_sd
@@ -72,8 +76,12 @@ lsm_l_circle_sd.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_circle_sd
@@ -84,8 +92,12 @@ lsm_l_circle_sd.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_circle_sd
@@ -98,8 +110,12 @@ lsm_l_circle_sd.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_circle_sd
@@ -110,25 +126,30 @@ lsm_l_circle_sd.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_circle_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_circle_sd_calc <- function(landscape, directions,
                                  resolution = NULL, points = NULL) {
 
-    circle_sd <- dplyr::summarize(lsm_p_circle_calc(landscape,
-                                                    directions = directions,
-                                                    resolution = resolution,
-                                                    points = points),
-                                  value = stats::sd(value))
+    circle_patch <- lsm_p_circle_calc(landscape,
+                                      directions = directions,
+                                      resolution = resolution,
+                                      points = points)
+
+    circle_sd <- stats::sd(circle_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "circle_sd",
-        value = as.double(circle_sd$value)
+        value = as.double(circle_sd)
     )
 
 }
