@@ -50,8 +50,12 @@ lsm_l_cohesion.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_cohesion_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_cohesion
@@ -62,8 +66,12 @@ lsm_l_cohesion.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_cohesion_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_cohesion
@@ -74,8 +82,12 @@ lsm_l_cohesion.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_cohesion_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_cohesion
@@ -88,8 +100,12 @@ lsm_l_cohesion.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_cohesion_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_cohesion
@@ -100,8 +116,12 @@ lsm_l_cohesion.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_cohesion_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_cohesion_calc <- function(landscape, directions, resolution = NULL) {
@@ -116,10 +136,11 @@ lsm_l_cohesion_calc <- function(landscape, directions, resolution = NULL) {
     ncells_landscape <- length(landscape[!is.na(landscape)])
 
     # get number of cells in each patch: area = n_cells * res / 10000
-    ncells_patch <- dplyr::mutate(lsm_p_area_calc(landscape,
-                                                  directions = directions,
-                                                  resolution = resolution),
-                                  value = value * 10000 / prod(resolution))
+    ncells_patch <- lsm_p_area_calc(landscape,
+                                    directions = directions,
+                                    resolution = resolution)
+
+    ncells_patch$value <- ncells_patch$value * 10000 / prod(resolution)
 
     # get perim for each patch
     perim_patch <- lsm_p_perim_calc(landscape,
@@ -127,21 +148,17 @@ lsm_l_cohesion_calc <- function(landscape, directions, resolution = NULL) {
                                     resolution = resolution)
 
     # denominator for cohesion (perim / n_cells) for landscape
-    denominator <- dplyr::summarise(dplyr::mutate(perim_patch,
-                                                  value = value * sqrt(ncells_patch$value)),
-                                    value = sum(value))
+    denominator <- sum(perim_patch$value * sqrt(ncells_patch$value))
 
     # calcualte cohesion
-    cohesion <- dplyr::mutate(dplyr::summarise(perim_patch,
-                                               value = sum(value)),
-                              value = (1 - (value / denominator$value)) *
-                                  ((1 - (1 / sqrt(ncells_landscape))) ^ - 1) * 100)
+    cohesion <- (1 - (sum(perim_patch$value) / denominator)) *
+        ((1 - (1 / sqrt(ncells_landscape))) ^ - 1) * 100
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "cohesion",
-        value = as.double(cohesion$value)
+        value = as.double(cohesion)
     )
 }
