@@ -66,8 +66,12 @@ lsm_l_contig_sd.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_contig_sd
@@ -78,8 +82,12 @@ lsm_l_contig_sd.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_contig_sd
@@ -90,8 +98,12 @@ lsm_l_contig_sd.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_contig_sd
@@ -104,8 +116,12 @@ lsm_l_contig_sd.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_contig_sd
@@ -116,20 +132,26 @@ lsm_l_contig_sd.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_contig_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_contig_sd_calc <- function(landscape, directions) {
 
-    contig_sd <- dplyr::summarize(lsm_p_contig_calc(landscape, directions = directions),
-                                  value = sd(value))
+    contig_patch <- lsm_p_contig_calc(landscape,
+                                      directions = directions)
+
+    contig_sd <- stats::sd(contig_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "contig_sd",
-        value = as.double(contig_sd$value)
+        value = as.double(contig_sd)
     )
 }
