@@ -66,8 +66,12 @@ lsm_l_dcore_cv.RasterLayer <- function(landscape,
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_dcore_cv
@@ -83,8 +87,12 @@ lsm_l_dcore_cv.RasterStack <- function(landscape,
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_dcore_cv
@@ -100,8 +108,12 @@ lsm_l_dcore_cv.RasterBrick <- function(landscape,
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_dcore_cv
@@ -119,8 +131,12 @@ lsm_l_dcore_cv.stars <- function(landscape,
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_dcore_cv
@@ -136,25 +152,30 @@ lsm_l_dcore_cv.list <- function(landscape,
                      consider_boundary = consider_boundary,
                      edge_depth = edge_depth)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_dcore_cv_calc <- function(landscape, directions, consider_boundary, edge_depth,
                                 points = NULL){
 
-    dcore_cv <- dplyr::summarise(lsm_p_ncore_calc(landscape,
-                                                  directions = directions,
-                                                  consider_boundary = consider_boundary,
-                                                  edge_depth = edge_depth,
-                                                  points = points),
-                                 value = raster::cv(value))
+    dcore_patch <- lsm_p_ncore_calc(landscape,
+                                    directions = directions,
+                                    consider_boundary = consider_boundary,
+                                    edge_depth = edge_depth,
+                                    points = points)
+
+    dcore_cv <- raster::cv(dcore_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "dcore_cv",
-        value = as.double(dcore_cv$value)
+        value = as.double(dcore_cv)
     )
 }
