@@ -53,8 +53,12 @@ lsm_l_division.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_division_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_division
@@ -65,8 +69,12 @@ lsm_l_division.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_division_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_division
@@ -77,8 +85,12 @@ lsm_l_division.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_division_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_division
@@ -91,8 +103,12 @@ lsm_l_division.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_division_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_division
@@ -103,8 +119,12 @@ lsm_l_division.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_division_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_division_calc <- function(landscape, directions, resolution = NULL) {
@@ -115,20 +135,19 @@ lsm_l_division_calc <- function(landscape, directions, resolution = NULL) {
                                   resolution = resolution)
 
     # summarise to total area
-    area_total <- dplyr::summarise(area_patch, value = sum(value))
+    area_total <- sum(area_patch$value)
 
     # divison for each patch
-    division <- dplyr::mutate(area_patch, value = (value / area_total$value) ^ 2)
+    area_patch$value <- (area_patch$value / area_total) ^ 2
 
     # summarise for whole landscape
-    division <- dplyr::mutate(dplyr::summarise(division, value = sum(value)),
-                              value = 1 - value)
+    division <- 1 - sum(area_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "division",
-        value = as.double(division$value)
+        value = as.double(division)
     )
 }
