@@ -57,8 +57,12 @@ lsm_l_ed.RasterLayer <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_ed
@@ -71,8 +75,12 @@ lsm_l_ed.RasterStack <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_ed
@@ -85,8 +93,12 @@ lsm_l_ed.RasterBrick <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_ed
@@ -101,8 +113,12 @@ lsm_l_ed.stars <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_ed
@@ -115,8 +131,12 @@ lsm_l_ed.list <- function(landscape,
                      count_boundary = count_boundary,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_ed_calc <- function(landscape, count_boundary, directions, resolution = NULL) {
@@ -133,7 +153,7 @@ lsm_l_ed_calc <- function(landscape, count_boundary, directions, resolution = NU
                                   resolution = resolution)
 
     # summarise to total area
-    area_total <- dplyr::summarise(area_patch, value = sum(value))
+    area_total <- sum(area_patch$value)
 
     # get total edge
     edge_landscape <- lsm_l_te_calc(landscape,
@@ -141,14 +161,13 @@ lsm_l_ed_calc <- function(landscape, count_boundary, directions, resolution = NU
                                     resolution = resolution)
 
     # relative edge density
-    ed <- dplyr::mutate(edge_landscape,
-                        value = value / area_total$value)
+    ed <- edge_landscape$value / area_total
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "ed",
-        value = as.double(ed$value)
+        value = as.double(ed)
     )
 }
