@@ -59,8 +59,12 @@ lsm_l_frac_cv.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_frac_cv
@@ -71,8 +75,12 @@ lsm_l_frac_cv.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_frac_cv
@@ -83,8 +91,12 @@ lsm_l_frac_cv.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_frac_cv
@@ -97,8 +109,12 @@ lsm_l_frac_cv.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_frac_cv
@@ -109,22 +125,27 @@ lsm_l_frac_cv.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_frac_cv_calc <- function(landscape, directions, resolution = NULL){
 
-    frac_cv <- dplyr::summarise(lsm_p_frac_calc(landscape,
-                                                directions = directions,
-                                                resolution = resolution),
-                                value = raster::cv(value))
+    frac_patch <- lsm_p_frac_calc(landscape,
+                                  directions = directions,
+                                  resolution = resolution)
+
+    frac_cv <- raster::cv(frac_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "frac_cv",
-        value = as.double(frac_cv$value)
+        value = as.double(frac_cv)
     )
 }
