@@ -58,8 +58,12 @@ lsm_l_frac_sd.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_frac_sd
@@ -70,8 +74,12 @@ lsm_l_frac_sd.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_frac_sd
@@ -82,8 +90,12 @@ lsm_l_frac_sd.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_frac_sd
@@ -96,8 +108,12 @@ lsm_l_frac_sd.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_frac_sd
@@ -108,22 +124,27 @@ lsm_l_frac_sd.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_frac_sd_calc <- function(landscape, directions, resolution = NULL){
 
-    frac_sd <- dplyr::summarise(lsm_p_frac_calc(landscape,
-                                                directions = directions,
-                                                resolution = resolution),
-                                value = stats::sd(value))
+    frac_patch <- lsm_p_frac_calc(landscape,
+                                  directions = directions,
+                                  resolution = resolution)
+
+    frac_sd <- stats::sd(frac_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "frac_sd",
-        value = as.double(frac_sd$value)
+        value = as.double(frac_sd)
     )
 }
