@@ -59,8 +59,12 @@ lsm_l_gyrate_sd.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_gyrate_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_gyrate_sd
@@ -71,8 +75,12 @@ lsm_l_gyrate_sd.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_gyrate_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_gyrate_sd
@@ -83,8 +91,12 @@ lsm_l_gyrate_sd.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_gyrate_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_gyrate_sd
@@ -97,8 +109,12 @@ lsm_l_gyrate_sd.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_gyrate_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_gyrate_sd
@@ -109,24 +125,29 @@ lsm_l_gyrate_sd.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_gyrate_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_gyrate_sd_calc <- function(landscape, directions,
                                  points = NULL) {
 
-    gyrate_sd <- dplyr::summarize(lsm_p_gyrate_calc(landscape,
-                                                    directions = directions,
-                                                    points = points),
-                                  value = stats::sd(value))
+    gyrate_patch <- lsm_p_gyrate_calc(landscape,
+                                      directions = directions,
+                                      points = points)
+
+    gyrate_sd <- stats::sd(gyrate_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "gyrate_sd",
-        value = as.double(gyrate_sd$value)
+        value = as.double(gyrate_sd)
     )
 }
 
