@@ -56,8 +56,12 @@ lsm_l_para_sd.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_para_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_para_sd
@@ -68,8 +72,12 @@ lsm_l_para_sd.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_para_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_para_sd
@@ -80,8 +88,12 @@ lsm_l_para_sd.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_para_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_para_sd
@@ -94,8 +106,12 @@ lsm_l_para_sd.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_para_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_para_sd
@@ -106,22 +122,27 @@ lsm_l_para_sd.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_para_sd_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_para_sd_calc <- function(landscape, directions, resolution = NULL){
 
-    para_sd <- dplyr::summarise(lsm_p_para_calc(landscape,
-                                                directions = directions,
-                                                resolution = resolution),
-                                value = stats::sd(value))
+    para_patch <- lsm_p_para_calc(landscape,
+                                  directions = directions,
+                                  resolution = resolution)
+
+    para_sd <- stats::sd(para_patch$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "para_sd",
-        value = as.double(para_sd$value)
+        value = as.double(para_sd)
     )
 }
