@@ -57,8 +57,12 @@ lsm_l_shape_cv.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_shape_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_shape_cv
@@ -69,8 +73,12 @@ lsm_l_shape_cv.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_shape_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_shape_cv
@@ -81,8 +89,12 @@ lsm_l_shape_cv.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_shape_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_shape_cv
@@ -95,8 +107,12 @@ lsm_l_shape_cv.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_shape_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_shape_cv
@@ -107,8 +123,12 @@ lsm_l_shape_cv.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_shape_cv_calc,
                      directions = directions)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_shape_cv_calc <- function(landscape, directions, resolution = NULL){
@@ -119,14 +139,13 @@ lsm_l_shape_cv_calc <- function(landscape, directions, resolution = NULL){
                               resolution = resolution)
 
     # calculate cv
-    shape_cv <- dplyr::summarise(shape,
-                                 value = raster::cv(value))
+    shape_cv <- raster::cv(shape$value)
 
     tibble::tibble(
         level = "landscape",
         class = as.integer(NA),
         id = as.integer(NA),
         metric = "shape_cv",
-        value = as.double(shape_cv$value)
+        value = as.double(shape_cv)
     )
 }
