@@ -49,8 +49,12 @@ lsm_l_te.RasterLayer <- function(landscape,  count_boundary = FALSE) {
                      FUN = lsm_l_te_calc,
                      count_boundary = count_boundary)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_te
@@ -61,8 +65,12 @@ lsm_l_te.RasterStack <- function(landscape,  count_boundary = FALSE) {
                      FUN = lsm_l_te_calc,
                      count_boundary = count_boundary)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_te
@@ -73,8 +81,12 @@ lsm_l_te.RasterBrick <- function(landscape, count_boundary = FALSE) {
                      FUN = lsm_l_te_calc,
                      count_boundary = count_boundary)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_te
@@ -87,8 +99,12 @@ lsm_l_te.stars <- function(landscape, count_boundary = FALSE) {
                      FUN = lsm_l_te_calc,
                      count_boundary = count_boundary)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_l_te
@@ -99,8 +115,12 @@ lsm_l_te.list <- function(landscape, count_boundary = FALSE) {
                      FUN = lsm_l_te_calc,
                      count_boundary = count_boundary)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_l_te_calc <- function(landscape, count_boundary, resolution = NULL){
@@ -118,7 +138,8 @@ lsm_l_te_calc <- function(landscape, count_boundary, resolution = NULL){
     if(isTRUE(count_boundary)){
         landscape <- pad_raster(landscape = landscape,
                                 pad_raster_value = max(landscape, na.rm = TRUE) + 1,
-                                pad_raster_cells = 1)
+                                pad_raster_cells = 1,
+                                return_raster = FALSE)[[1]]
     }
 
     if (isTRUE(resolution_x == resolution_y)) {
