@@ -62,8 +62,12 @@ lsm_p_enn.RasterLayer <- function(landscape, directions = 8, verbose = TRUE) {
                      directions = directions,
                      verbose = verbose)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_p_enn
@@ -75,8 +79,12 @@ lsm_p_enn.RasterStack <- function(landscape, directions = 8, verbose = TRUE) {
                      directions = directions,
                      verbose = verbose)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_p_enn
@@ -88,8 +96,12 @@ lsm_p_enn.RasterBrick <- function(landscape, directions = 8, verbose = TRUE) {
                      directions = directions,
                      verbose = verbose)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+     layer <- rep(seq_len(length(result)),
+                  vapply(result, nrow, FUN.VALUE = integer(1)))
+
+     result <- do.call(rbind, result)
+
+     tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_p_enn
@@ -103,8 +115,12 @@ lsm_p_enn.stars <- function(landscape, directions = 8, verbose = TRUE) {
                      directions = directions,
                      verbose = verbose)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 #' @name lsm_p_enn
@@ -116,8 +132,12 @@ lsm_p_enn.list <- function(landscape, directions = 8, verbose = TRUE) {
                      directions = directions,
                      verbose = verbose)
 
-    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
-                  layer = as.integer(layer))
+    layer <- rep(seq_len(length(result)),
+                 vapply(result, nrow, FUN.VALUE = integer(1)))
+
+    result <- do.call(rbind, result)
+
+    tibble::add_column(result, layer, .before = TRUE)
 }
 
 lsm_p_enn_calc <- function(landscape, directions, verbose,
@@ -136,7 +156,8 @@ lsm_p_enn_calc <- function(landscape, directions, verbose,
     # get unique classes
     classes <- get_unique_values(landscape)[[1]]
 
-    enn_patch <- lapply(classes, function(patches_class) {
+    enn_patch <- do.call(rbind,
+                         lapply(classes, function(patches_class) {
 
         # get connected patches
         landscape_labeled <- get_patches(landscape,
@@ -150,8 +171,8 @@ lsm_p_enn_calc <- function(landscape, directions, verbose,
         # ENN doesn't make sense if only one patch is present
         if(np_class == 1) {
 
-            enn <-  tibble::tibble(class = patches_class,
-                                   value = as.double(NA))
+            enn <- tibble::tibble(class = patches_class,
+                                  dist = as.double(NA))
 
             if(isTRUE(verbose)) {
                 warning(paste0("Class ", patches_class,
@@ -196,15 +217,13 @@ lsm_p_enn_calc <- function(landscape, directions, verbose,
                                   id = min_dist[,3])
 
             # only get minimum value for each patch
-            enn <- dplyr::summarise(dplyr::group_by(tbl, by = id),
-                                    value = min(dist))
+            enn <- stats::aggregate(x = tbl[, 2], by = tbl[, 3], FUN = min)
         }
 
         tibble::tibble(class = patches_class,
-                       value = enn$value)
-    })
-
-    enn_patch <- dplyr::bind_rows(enn_patch)
+                       value = enn$dist)
+        })
+    )
 
     tibble::tibble(level = "patch",
                    class = as.integer(enn_patch$class),
@@ -212,92 +231,3 @@ lsm_p_enn_calc <- function(landscape, directions, verbose,
                    metric = "enn",
                    value = as.double(enn_patch$value))
 }
-
-# lsm_p_enn_calc_old <- function(landscape, directions, verbose,
-#                            extent = NULL, resolution = NULL, crs = NULL) {
-#
-#     # use raster instead of landscape
-#     if(class(landscape) == "matrix") {
-#         landscape <- matrix_to_raster(landscape,
-#                                       extent = extent,
-#                                       resolution = resolution,
-#                                       crs =crs)
-#     }
-#
-#
-#     # get unique classes
-#     classes <- get_unique_values(landscape)[[1]]
-#
-#     enn_patch <- lapply(classes, function(patches_class) {
-#
-#         # get connected patches
-#         landscape_labeled <- get_patches(landscape,
-#                                          class = patches_class,
-#                                          directions = directions)[[1]]
-#
-#         # get number of patches
-#         np_class <- raster::maxValue(landscape_labeled)
-#
-#         # ENN doesn't make sense if only one patch is present
-#         if(np_class == 1) {
-#
-#             enn <-  tibble::tibble(class = patches_class,
-#                                    value = as.double(NA))
-#
-#             if(isTRUE(verbose)) {
-#                 warning(paste0("Class ", patches_class,
-#                                ": ENN = NA for class with only 1 patch"),
-#                         call. = FALSE)
-#             }
-#         }
-#
-#         else {
-#
-#             # get edge cells because only they are important for ENN
-#             class_boundaries <- get_boundaries(landscape_labeled,
-#                                                directions = 4,
-#                                                as_NA = TRUE)
-#
-#             # set edge cell value to patch id
-#             raster::values(class_boundaries)[raster::values(!is.na(class_boundaries))] <- raster::values(landscape_labeled)[raster::values(!is.na(class_boundaries))]
-#
-#             # conver to points to calculate distances
-#             points_class <- raster::rasterToPoints(class_boundaries)
-#
-#             # order points
-#             ord <- order(as.matrix(points_class)[, 1])
-#             num <- seq_along(ord)
-#             rank <- match(num, ord)
-#
-#             # get nearest neighbor between patches
-#             res <- rcpp_get_nearest_neighbor(as.matrix(points_class)[ord,])
-#
-#             # order results
-#             min_dist <- unname(cbind(num, res[rank], as.matrix(points_class)[, 3]))
-#
-#             tbl <- tibble::tibble(cell = min_dist[,1],
-#                                   dist = min_dist[,2],
-#                                   id = min_dist[,3])
-#
-#             # only get minimum value for each patch
-#             enn <- dplyr::summarise(dplyr::group_by(tbl, by = id),
-#                                     value = min(dist))
-#         }
-#
-#         tibble::tibble(class = patches_class,
-#                        value = enn$value)
-#     })
-#
-#     enn_patch <- dplyr::bind_rows(enn_patch)
-#
-#     tibble::tibble(level = "patch",
-#                    class = as.integer(enn_patch$class),
-#                    id = as.integer(seq_len(nrow(enn_patch))),
-#                    metric = "enn",
-#                    value = as.double(enn_patch$value))
-# }
-
-# bench::mark(
-#     new <- lsm_p_enn_calc(landscape, directions = 8),
-#     old <- lsm_p_enn_calc_old(landscape, directions = 8),
-#     iterations = 25)
